@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2012 Free Software Foundation, Inc.
+ * Copyright (C) 2002-2013 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -21,30 +21,30 @@
  */
 
 #ifndef LIBTASN1_H
-# define LIBTASN1_H
+#define LIBTASN1_H
 
-# ifndef ASN1_API
-#  if defined ASN1_BUILDING && defined HAVE_VISIBILITY && HAVE_VISIBILITY
-#   define ASN1_API __attribute__((__visibility__("default")))
-#  elif defined ASN1_BUILDING && defined _MSC_VER && ! defined ASN1_STATIC
-#   define ASN1_API __declspec(dllexport)
-#  elif defined _MSC_VER && ! defined ASN1_STATIC
-#   define ASN1_API __declspec(dllimport)
-#  else
-#   define ASN1_API
-#  endif
-# endif
+#ifndef ASN1_API
+#if defined ASN1_BUILDING && defined HAVE_VISIBILITY && HAVE_VISIBILITY
+#define ASN1_API __attribute__((__visibility__("default")))
+#elif defined ASN1_BUILDING && defined _MSC_VER && ! defined ASN1_STATIC
+#define ASN1_API __declspec(dllexport)
+#elif defined _MSC_VER && ! defined ASN1_STATIC
+#define ASN1_API __declspec(dllimport)
+#else
+#define ASN1_API
+#endif
+#endif
 
-#include <stdio.h>		/* for FILE* */
 #include <sys/types.h>
 #include <time.h>
+#include <stdio.h>		/* for FILE* */
 
 #ifdef __cplusplus
 extern "C"
 {
 #endif
 
-#define ASN1_VERSION "3.2"
+#define ASN1_VERSION "3.3"
 
   /*****************************************/
   /* Errors returned by libtasn1 functions */
@@ -172,7 +172,7 @@ extern "C"
   {
     const char *name;		/* Node name */
     const void *value;		/* Node value */
-    unsigned int value_len;     /* Node value size */
+    unsigned int value_len;	/* Node value size */
     unsigned int type;		/* Node value type (ASN1_ETYPE_*) */
   };
   typedef struct asn1_data_node_st asn1_data_node_st;
@@ -192,13 +192,13 @@ extern "C"
   /***********************************/
 
   extern ASN1_API int
-    asn1_parser2tree (const char *file_name,
-		      asn1_node * definitions, char *errorDescription);
+    asn1_parser2tree (const char *file,
+		      asn1_node * definitions, char *error_desc);
 
   extern ASN1_API int
     asn1_parser2array (const char *inputFileName,
 		       const char *outputFileName,
-		       const char *vectorName, char *errorDescription);
+		       const char *vectorName, char *error_desc);
 
   extern ASN1_API int
     asn1_array2tree (const asn1_static_node * array,
@@ -227,10 +227,10 @@ extern "C"
 
   extern ASN1_API int
     asn1_read_value_type (asn1_node root, const char *name,
-		          void *ivalue, int *len, unsigned int* etype);
+			  void *ivalue, int *len, unsigned int *etype);
 
   extern ASN1_API int
-    asn1_read_node_value (asn1_node node, asn1_data_node_st* data);
+    asn1_read_node_value (asn1_node node, asn1_data_node_st * data);
 
   extern ASN1_API int
     asn1_number_of_elements (asn1_node element, const char *name, int *num);
@@ -288,17 +288,20 @@ extern "C"
     asn1_get_length_ber (const unsigned char *ber, int ber_len, int *len);
 
   extern ASN1_API void
-    asn1_length_der (unsigned long int len, unsigned char *ans, int *ans_len);
+    asn1_length_der (unsigned long int len, unsigned char *der, int *der_len);
 
   /* Other utility functions. */
 
-  extern ASN1_API 
-    int asn1_decode_simple_der (unsigned int etype, const unsigned char *der, unsigned int der_len,
-                        const unsigned char **str, unsigned int *str_len);
+  extern ASN1_API
+    int asn1_decode_simple_der (unsigned int etype, const unsigned char *der,
+				unsigned int der_len,
+				const unsigned char **str,
+				unsigned int *str_len);
 
   extern ASN1_API int
-    asn1_encode_simple_der (unsigned int etype, const unsigned char *str, unsigned int str_len,
-                        unsigned char *tl, unsigned int *tl_len);
+    asn1_encode_simple_der (unsigned int etype, const unsigned char *str,
+			    unsigned int str_len, unsigned char *tl,
+			    unsigned int *tl_len);
 
   extern ASN1_API asn1_node
     asn1_find_node (asn1_node pointer, const char *name);
@@ -332,7 +335,7 @@ extern "C"
 
 /* Compatibility types */
 
-typedef int asn1_retCode;	/* type returned by libtasn1 functions */
+  typedef int asn1_retCode;	/* type returned by libtasn1 functions */
 
 #define node_asn_struct asn1_node_st
 #define node_asn asn1_node_st
