@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2012 Free Software Foundation, Inc.
+ * Copyright (C) 2002-2013 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -36,18 +36,24 @@ int data_size = sizeof (data);
 int
 main (int argc, char *argv[])
 {
-  asn1_retCode result;
-  ASN1_TYPE definitions = ASN1_TYPE_EMPTY;
-  ASN1_TYPE asn1_element = ASN1_TYPE_EMPTY;
+  int result, verbose = 0;
+  asn1_node definitions = NULL;
+  asn1_node asn1_element = NULL;
   char errorDescription[ASN1_MAX_ERROR_DESCRIPTION_SIZE];
   const char *treefile = getenv ("ASN1ENCODING");
 
+  if (argc > 1)
+    verbose = 1;
+
   if (!treefile)
     treefile = "Test_encoding.asn";
 
-  printf ("\n\n/****************************************/\n");
-  printf ("/*     Test sequence : coding-decoding  */\n");
-  printf ("/****************************************/\n\n");
+  if (verbose != 0)
+    {
+      printf ("\n\n/****************************************/\n");
+      printf ("/*     Test sequence : coding-decoding  */\n");
+      printf ("/****************************************/\n\n");
+    }
 
   /* Check version */
   if (asn1_check_version ("0.3.3") == NULL)
@@ -124,6 +130,7 @@ main (int argc, char *argv[])
 
   asn1_delete_structure (&asn1_element);
 
-  printf ("Success\n");
+  if (verbose)
+    printf ("Success\n");
   exit (0);
 }
