@@ -1,6 +1,5 @@
 /*
- * Copyright (C) 2002, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
- * Foundation, Inc.
+ * Copyright (C) 2002-2013 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -40,15 +39,19 @@
 int
 main (int argc, char *argv[])
 {
-  asn1_retCode result;
+  int result;
   char buffer[10 * 1024];
-  ASN1_TYPE definitions = ASN1_TYPE_EMPTY;
-  ASN1_TYPE asn1_element = ASN1_TYPE_EMPTY;
+  asn1_node definitions = NULL;
+  asn1_node asn1_element = NULL;
   char errorDescription[ASN1_MAX_ERROR_DESCRIPTION_SIZE];
   FILE *out, *fd;
   ssize_t size;
   const char *treefile = getenv ("ASN1PKIX");
   const char *indeffile = getenv ("ASN1INDEF");
+  int verbose = 0;
+
+  if (argc > 1)
+    verbose = 1;
 
   if (!treefile)
     treefile = "pkix.asn";
@@ -56,10 +59,13 @@ main (int argc, char *argv[])
   if (!indeffile)
     indeffile = "TestIndef.p12";
 
-  printf ("\n\n/****************************************/\n");
-  printf ("/*     Test sequence : Test_indefinite  */\n");
-  printf ("/****************************************/\n\n");
-  printf ("ASN1TREE: %s\n", treefile);
+  if (verbose)
+    {
+      printf ("\n\n/****************************************/\n");
+      printf ("/*     Test sequence : Test_indefinite  */\n");
+      printf ("/****************************************/\n\n");
+      printf ("ASN1TREE: %s\n", treefile);
+    }
 
   /* Check version */
   if (asn1_check_version ("0.2.11") == NULL)
@@ -104,7 +110,7 @@ main (int argc, char *argv[])
   if (result != ASN1_SUCCESS)
     {
       asn1_perror (result);
-      printf ("Cannot decode BER data (size %d)\n", size);
+      printf ("Cannot decode BER data (size %ld)\n", (long) size);
       exit (1);
     }
 
