@@ -1,6 +1,5 @@
 /*
- * Copyright (C) 2002, 2006, 2007, 2009, 2010 Free Software
- * Foundation, Inc.
+ * Copyright (C) 2002-2013 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -34,12 +33,12 @@
 typedef struct
 {
   int lineNumber;
-  char *line;
+  const char *line;
   int errorNumber;
-  char *errorDescription;
+  const char *errorDescription;
 } test_type;
 
-char *fileCorrectName;
+const char *fileCorrectName;
 char fileErroredName[] = "Test_parser_ERROR.asn";
 
 #define _FILE_ "Test_parser_ERROR.asn"
@@ -48,18 +47,19 @@ test_type test_array[] = {
   /* Test DEFINITIONS syntax */
   {5,
    "TEST_PARSER2 { } DEFINITIONS IMPLICIT TAGS ::= BEGIN int1 ::= INTEGER END",
-   ASN1_SYNTAX_ERROR, _FILE_ ":6: parse error near 'TEST_PARSER'"},
+   ASN1_SYNTAX_ERROR,
+   _FILE_
+   ":6: Error: syntax error, unexpected IDENTIFIER, expecting $end near 'TEST_PARSER'"},
   {6, "TEST_PARSER { }", ASN1_SUCCESS, ""},
 
   /* Test ASN1_MAX_NAME_SIZE (128) */
   {12,
-   "a1234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567 ::= INTEGER",
+   "a123456789012345678901234567890123456789012345678901234567890123 ::= INTEGER",
    ASN1_SUCCESS, ""},
   {12,
-   "a12345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678 ::= INTEGER",
+   "a1234567890123456789012345678901234567890123456789012345678901234 ::= INTEGER",
    ASN1_NAME_TOO_LONG,
-   _FILE_ ":12: name too long (more than 128 characters)"},
-
+   _FILE_ ":12: name too long (more than 64 characters)"},
   /* Test 'check identifier' function */
   {12, "ident1 ::= ident2   ident2 ::= INTEGER",
    ASN1_SUCCESS, ""},
@@ -81,13 +81,18 @@ test_type test_array[] = {
   {14, "int1 [1] IMPLICIT INTEGER,", ASN1_SUCCESS, ""},
   {12, "Integer ::= [1] EXPLICIT INTEGER {v1(-1), v2(1)}", ASN1_SUCCESS, ""},
   {12, "Integer ::= INTEGER {v1(0), v2}",
-   ASN1_SYNTAX_ERROR, _FILE_ ":12: parse error near '}'"},
+   ASN1_SYNTAX_ERROR,
+   _FILE_ ":12: Error: syntax error, unexpected '}', expecting '(' near '}'"},
   {12, "Integer ::= INTEGER {v1(0), 1}",
-   ASN1_SYNTAX_ERROR, _FILE_ ":12: parse error near '1'"},
+   ASN1_SYNTAX_ERROR,
+   _FILE_
+   ":12: Error: syntax error, unexpected NUM, expecting IDENTIFIER or '(' near '1'"},
   {12, "const1 INTEGER ::= -1", ASN1_SUCCESS, ""},
   {12, "const1 INTEGER ::= 1", ASN1_SUCCESS, ""},
   {12, "const1 INTEGER ::= v1",
-   ASN1_SYNTAX_ERROR, _FILE_ ":12: parse error near 'v1'"},
+   ASN1_SYNTAX_ERROR,
+   _FILE_
+   ":12: Error: syntax error, unexpected IDENTIFIER, expecting NUM or '+' or '-' near 'v1'"},
   {16, " generic generalstring",
    ASN1_IDENTIFIER_NOT_FOUND,
    _FILE_ ":: identifier 'generalstring' not found"},
@@ -98,16 +103,16 @@ test_type test_array[] = {
   {20, "   oid1    OBJECT IDENTIFIER DEFAULT 1",
    ASN1_IDENTIFIER_NOT_FOUND, _FILE_ ":: identifier '1' not found"},
   {20, "   oid1    OBJECT IDENTIFIER DEFAULT",
-   ASN1_SYNTAX_ERROR, _FILE_ ":21: parse error near '}'"},
+   ASN1_SYNTAX_ERROR,
+   _FILE_ ":21: Error: syntax error, unexpected '}' near '}'"},
   {20, "   oid1    OBJECT IDENTIFIER DEFAULT Oid-type1",
    ASN1_SUCCESS, ""},
 
-
   /* end */
   {0}
 };
 
-int
+static int
 readLine (FILE * file, char *line)
 {
   int c;
@@ -123,9 +128,8 @@ readLine (FILE * file, char *line)
   return c;
 }
 
-
-void
-createFile (int lineNumber, char *line)
+static void
+createFile (int lineNumber, const char *line)
 {
   FILE *fileIn, *fileOut;
   char lineRead[1024];
@@ -151,20 +155,27 @@ createFile (int lineNumber, char *line)
 int
 main (int argc, char *argv[])
 {
-  asn1_retCode result;
-  ASN1_TYPE definitions = ASN1_TYPE_EMPTY;
+  int result;
+  asn1_node definitions = NULL;
   char errorDescription[ASN1_MAX_ERROR_DESCRIPTION_SIZE];
   test_type *test;
   int errorCounter = 0, testCounter = 0;
+  int verbose = 0;
+
+  if (argc > 1)
+    verbose = 1;
 
   fileCorrectName = getenv ("ASN1PARSER");
   if (!fileCorrectName)
     fileCorrectName = "Test_parser.asn";
 
-  printf ("\n\n/****************************************/\n");
-  printf ("/*     Test sequence : Test_parser      */\n");
-  printf ("/****************************************/\n\n");
-  printf ("ASN1PARSER: %s\n", fileCorrectName);
+  if (verbose != 0)
+    {
+      printf ("\n\n/****************************************/\n");
+      printf ("/*     Test sequence : Test_parser      */\n");
+      printf ("/****************************************/\n\n");
+      printf ("ASN1PARSER: %s\n", fileCorrectName);
+    }
 
   result = asn1_parser2tree (fileCorrectName, &definitions, errorDescription);
 
@@ -205,14 +216,18 @@ main (int argc, char *argv[])
 		  asn1_strerror (test->errorNumber), test->errorDescription);
 	  printf ("  Error detected: %s - %s\n\n", asn1_strerror (result),
 		  errorDescription);
+	  exit (1);
 	}
 
       test++;
     }
 
 
-  printf ("Total tests : %d\n", testCounter);
-  printf ("Total errors: %d\n", errorCounter);
+  if (verbose != 0)
+    {
+      printf ("Total tests : %d\n", testCounter);
+      printf ("Total errors: %d\n", errorCounter);
+    }
 
   if (errorCounter > 0)
     return 1;
